@@ -358,11 +358,32 @@ const char *vips_foreign_find_save_target( const char *suffix );
 
 int vips_vipsload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_vipsload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_vipssave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
+int vips_vipssave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
 
 int vips_openslideload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_openslideload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
+
+/**
+ * VipsForeignSubsample:
+ * @VIPS_FOREIGN_SUBSAMPLE_AUTO: prevent subsampling when quality >= 90
+ * @VIPS_FOREIGN_SUBSAMPLE_ON: always perform subsampling
+ * @VIPS_FOREIGN_SUBSAMPLE_OFF: never perform subsampling
+ *
+ * Set subsampling mode.
+ */
+typedef enum {
+	VIPS_FOREIGN_SUBSAMPLE_AUTO,
+	VIPS_FOREIGN_SUBSAMPLE_ON,
+	VIPS_FOREIGN_SUBSAMPLE_OFF,
+	VIPS_FOREIGN_SUBSAMPLE_LAST
+} VipsForeignSubsample;
 
 /**
  * VipsForeignJpegSubsample:
@@ -371,6 +392,8 @@ int vips_openslideload( const char *filename, VipsImage **out, ... )
  * @VIPS_FOREIGN_JPEG_SUBSAMPLE_OFF: never perform subsampling
  *
  * Set jpeg subsampling mode.
+ *
+ * DEPRECATED: use #VipsForeignSubsample
  */
 typedef enum {
 	VIPS_FOREIGN_JPEG_SUBSAMPLE_AUTO,
@@ -383,6 +406,8 @@ int vips_jpegload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_jpegload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_jpegload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 
 int vips_jpegsave_target( VipsImage *in, VipsTarget *target, ... )
 	__attribute__((sentinel));
@@ -440,6 +465,7 @@ int vips_webpsave_mime( VipsImage *in, ... )
  * @VIPS_FOREIGN_TIFF_COMPRESSION_LZW: LZW compression
  * @VIPS_FOREIGN_TIFF_COMPRESSION_WEBP: WEBP compression
  * @VIPS_FOREIGN_TIFF_COMPRESSION_ZSTD: ZSTD compression
+ * @VIPS_FOREIGN_TIFF_COMPRESSION_JP2K: JP2K compression
  *
  * The compression types supported by the tiff writer.
  *
@@ -460,6 +486,7 @@ typedef enum {
 	VIPS_FOREIGN_TIFF_COMPRESSION_LZW,
 	VIPS_FOREIGN_TIFF_COMPRESSION_WEBP,
 	VIPS_FOREIGN_TIFF_COMPRESSION_ZSTD,
+	VIPS_FOREIGN_TIFF_COMPRESSION_JP2K,
 	VIPS_FOREIGN_TIFF_COMPRESSION_LAST
 } VipsForeignTiffCompression;
 
@@ -621,6 +648,8 @@ int vips_svgload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
 int vips_svgload_buffer( void *buf, size_t len, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_svgload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 
 int vips_gifload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
@@ -644,9 +673,37 @@ int vips_heifsave_target( VipsImage *in, VipsTarget *target, ... )
 
 int vips_niftiload( const char *filename, VipsImage **out, ... )
 	__attribute__((sentinel));
+int vips_niftiload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
 int vips_niftisave( VipsImage *in, const char *filename, ... )
 	__attribute__((sentinel));
 
+int vips_jp2kload( const char *filename, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jp2kload_buffer( void *buf, size_t len, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jp2kload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jp2ksave( VipsImage *in, const char *filename, ... )
+	__attribute__((sentinel));
+int vips_jp2ksave_buffer( VipsImage *in, void **buf, size_t *len, ... )
+	__attribute__((sentinel));
+int vips_jp2ksave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
+
+int vips_jxlload_source( VipsSource *source, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jxlload_buffer( void *buf, size_t len, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jxlload( const char *filename, VipsImage **out, ... )
+	__attribute__((sentinel));
+int vips_jxlsave( VipsImage *in, const char *filename, ... )
+	__attribute__((sentinel));
+int vips_jxlsave_buffer( VipsImage *in, void **buf, size_t *len, ... )
+	__attribute__((sentinel));
+int vips_jxlsave_target( VipsImage *in, VipsTarget *target, ... )
+	__attribute__((sentinel));
+
 /**
  * VipsForeignDzLayout:
  * @VIPS_FOREIGN_DZ_LAYOUT_DZ: use DeepZoom directory layout
